4.49. umbra.ui.widgets.active_QLabel — Umbra 1.0.9 documentation

# 4.49. umbra.ui.widgets.active_QLabel

active_QLabel.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `Active_QLabel` class.

Others:

## 4.49.1. Module Attributes

`umbra.ui.widgets.active_QLabel.` `LOGGER`

## 4.49.2. Classes

class `umbra.ui.widgets.active_QLabel.` `Active_QLabel`(parent=None, defaultPixmap=None, hoverPixmap=None, activePixmap=None, checkable=False, checked=False)

  Bases: `PyQt4.QtGui.QLabel`

  Defines a QLabel subclass providing a clickable label with hovering capabilities.

  Initializes the class.

  Parameters: | parent (QObject) – Widget parent. defaultPixmap (QPixmap) – Label default pixmap. hoverPixmap (QPixmap) – Label hover pixmap. activePixmap (QPixmap) – Label active pixmap. checkable (bool) – Checkable state. checked (bool) – Checked state.

  `clicked`

    This signal is emited by the `Active_QLabel` class when it has been clicked. ( pyqtSignal )

  `pressed`

    This signal is emited by the `Active_QLabel` class when it has been pressed. ( pyqtSignal )

  `released`

    This signal is emited by the `Active_QLabel` class when it has been released. ( pyqtSignal )

  `toggled`

    This signal is emited by the `Active_QLabel` class when it has been toggled. ( pyqtSignal )

    Returns: | Current checked state.
    Return type: | bool

  `defaultPixmap`

    Property for self.__defaultPixmap attribute.

    Returns: | self.__defaultPixmap.
    Return type: | QPixmap

  `hoverPixmap`

    Property for self.__hoverPixmap attribute.

    Returns: | self.__hoverPixmap.
    Return type: | QPixmap

  `activePixmap`

    Property for self.__activePixmap attribute.

    Returns: | self.__activePixmap.
    Return type: | QPixmap

  `checkable`

    Property for self.__checkable attribute.

    Returns: | self.__checkable.
    Return type: | bool

  `checked`

    Property for self.__checked attribute.

    Returns: | self.__checked.
    Return type: | bool

  `menu`

    Property for self.__menu attribute.

    Returns: | self.__menu.
    Return type: | QMenu

  `enterEvent`(event)

    Reimplements the `QLabel.enterEvent()` method.

    Parameters: | event (QEvent) – QEvent.

  `leaveEvent`(event)

    Reimplements the `QLabel.leaveEvent()` method.

    Parameters: | event (QEvent) – QEvent.

  `mousePressEvent`(event)

    Reimplements the `QLabel.mousePressEvent()` method.

    Parameters: | event (QEvent) – QEvent.

  `mouseReleaseEvent`(event)

    Reimplements the `QLabel.mouseReleaseEvent()` method.

    Parameters: | event (QEvent) – QEvent.

  `setChecked`(state)

    Sets the Widget checked state.

    Parameters: | state (bool) – New check state.
    Returns: | Method success.
    Return type: | bool

  `setMenu`(menu)

    Sets the Widget menu.

    Parameters: | menu (QMenu) – Menu.
    Returns: | Method success.
    Return type: | bool